This module contains all the actions that are performed in setup.  Actions that are performed in setup typically serve one of the the following two purposes:

- They load additional functionalities into PLUMED
- They make PLUMED aware of considerations that will affect how all the actions are performed. For example, these actions can be used to specify  the units in the unit file or that a restart calculation is being performed

